#!/bin/ksh

echodo ()
{
	echo $*
	$*
}

if [ "$#" -lt "1" ]
then
	echo "Usage: $0 <dir. location for datafiles>"
	exit
fi

DB=$ORACLE_SID
DB_DIR=$1

echodo ./schema_C.sh  ${DB} ${DB_DIR}
echodo ./schema_M.sh  ${DB} ${DB_DIR}
echodo ./schema_O.sh  ${DB} ${DB_DIR}
echodo ./schema_S.sh  ${DB} ${DB_DIR}
echodo ./schema_U.sh  ${DB} ${DB_DIR}
