 
sqlplus /nolog <<!
connect spec/spec;
spool disable_lock.log;
alter table M_INVENTORY disable table lock;                                    
alter table M_WORKORDER disable table lock;                                    
alter table S_SUPPLIER disable table lock;                                     
alter table M_PARTS disable table lock;                                        
alter table M_BOM disable table lock;                                          
alter table C_CUSTOMER disable table lock;                                     
alter table S_SUPP_COMPONENT disable table lock;                               
alter table O_ORDERLINE disable table lock;                                    
alter table O_ITEM disable table lock;                                         
alter table C_CUSTOMERINVENTORY disable table lock;                            
alter table O_ORDERS disable table lock;                                       
alter table M_LARGEORDER disable table lock;                                   
alter table C_SUPPLIER disable table lock;                                     
alter table S_PURCHASE_ORDER disable table lock;                               
alter table S_SITE disable table lock;                                         
alter table U_SEQUENCES disable table lock;                                    
alter table C_SITE disable table lock;                                         
alter table C_PARTS disable table lock;                                        
alter table S_PURCHASE_ORDERLINE disable table lock;                           
alter table S_COMPONENT disable table lock;                                    
exit;
!
