DROP TABLE U_sequences;
CREATE TABLE U_sequences
(
	s_id		varchar(50) not null,
	s_nextnum	integer,
	s_blocksize	integer
)
tablespace U_space
pctfree 98 pctused 2;
CREATE UNIQUE INDEX U_s_idx 
ON U_sequences (s_id)
tablespace U_space;
