#!/bin/ksh

. /home/oracle/db_scripts/db_env.sh

cd $ORACLE_HOME/dbs
DB=${ORACLE_SID}

VG_ORADATA=/dev/mapper
VG_ORALOG=/dev/mapper

ln -sf $VG_ORADATA/oradata-lv_wls_system sys_${DB}
ln -sf $VG_ORADATA/oradata-lv_wls_sysaux sysaux_${DB}
ln -sf $VG_ORADATA/oradata-lv_wls_temp temp_${DB}
ln -sf $VG_ORADATA/oradata-lv_wls_undo undo_${DB}
ln -sf $VG_ORADATA/oradata-lv_wls_controlfile cntrl_${DB}
ln -sf $VG_ORADATA/oradata-lv_wls_stats stats_${DB}
ln -sf $VG_ORADATA/oradata-lv_wls_llr llr_${DB}

ln -sf $VG_ORADATA/oradata-lv_wls_c_custinv C_custinv
ln -sf $VG_ORADATA/oradata-lv_wls_c_cust C_cust
ln -sf $VG_ORADATA/oradata-lv_wls_c_parts C_parts
ln -sf $VG_ORADATA/oradata-lv_wls_c_supp C_supp
ln -sf $VG_ORADATA/oradata-lv_wls_c_site C_site

ln -sf $VG_ORADATA/oradata-lv_wls_m_bom M_bom
ln -sf $VG_ORADATA/oradata-lv_wls_m_inv_idx M_inv_idx
ln -sf $VG_ORADATA/oradata-lv_wls_m_inv M_inv
ln -sf $VG_ORADATA/oradata-lv_wls_m_lo M_lrgorder
ln -sf $VG_ORADATA/oradata-lv_wls_m_parts M_parts
ln -sf $VG_ORADATA/oradata-lv_wls_m_wo M_wrkorder
ln -sf $VG_ORADATA/oradata-lv_wls_m_wo_idx M_wrkorder_idx

ln -sf $VG_ORADATA/oradata-lv_wls_o_item O_item
ln -sf $VG_ORADATA/oradata-lv_wls_o_ordl O_ordl
ln -sf $VG_ORADATA/oradata-lv_wls_o_ords O_ords

ln -sf $VG_ORADATA/oradata-lv_wls_s_comp S_comp
ln -sf $VG_ORADATA/oradata-lv_wls_s_po S_po
ln -sf $VG_ORADATA/oradata-lv_wls_s_sc S_suppcomp
ln -sf $VG_ORADATA/oradata-lv_wls_s_site S_site
ln -sf $VG_ORADATA/oradata-lv_wls_s_supp S_supp

ln -sf $VG_ORADATA/oradata-lv_wls_u_seq U_tables

ln -sf $VG_ORALOG/oralog-lv_wls_slog1 log1.f
ln -sf $VG_ORALOG/oralog-lv_wls_slog2 log2.f
