 
sqlplus /nolog <<!
connect spec/spec;
spool enable_lock.log;
alter table M_INVENTORY enable table lock;                                    
alter table M_WORKORDER enable table lock;                                    
alter table S_SUPPLIER enable table lock;                                     
alter table M_PARTS enable table lock;                                        
alter table M_BOM enable table lock;                                          
alter table C_CUSTOMER enable table lock;                                     
alter table S_SUPP_COMPONENT enable table lock;                               
alter table O_ORDERLINE enable table lock;                                    
alter table O_ITEM enable table lock;                                         
alter table C_CUSTOMERINVENTORY enable table lock;                            
alter table O_ORDERS enable table lock;                                       
alter table M_LARGEORDER enable table lock;                                   
alter table C_SUPPLIER enable table lock;                                     
alter table S_PURCHASE_ORDER enable table lock;                               
alter table S_SITE enable table lock;                                         
alter table U_SEQUENCES enable table lock;                                    
alter table C_SITE enable table lock;                                         
alter table C_PARTS enable table lock;                                        
alter table S_PURCHASE_ORDERLINE enable table lock;                           
alter table S_COMPONENT enable table lock;                                    
exit;
!
