#!/bin/ksh

echodo ()
{
 echo $*
 $*
}

echodo lvcreate -i 6 -I 32  -L 4224 -n lv_wls_system  oradata
echodo lvcreate -i 6 -I 32  -L 13440 -n lv_wls_sysaux  oradata
echodo lvcreate -i 6 -I 32  -L 82176 -n lv_wls_temp  oradata
echodo lvcreate -i 6 -I 32  -L 410112 -n lv_wls_undo oradata
echodo lvcreate -i 6 -I 32  -L 2304 -n lv_wls_controlfile  oradata
echodo lvcreate -i 6 -I 32  -L 10368 -n lv_wls_stats  oradata

echodo lvcreate -i 6 -I 32  -L 460800 -n lv_wls_c_custinv  oradata
echodo lvcreate -i 6 -I 32  -L 256128 -n lv_wls_c_cust  oradata
echodo lvcreate -i 6 -I 32  -L 17664 -n lv_wls_c_parts  oradata
echodo lvcreate -i 6 -I 32  -L 3072 -n lv_wls_c_supp  oradata
echodo lvcreate -i 6 -I 32  -L 3072 -n lv_wls_c_site  oradata

echodo lvcreate -i 6 -I 32  -L 15360 -n lv_wls_m_bom  oradata
echodo lvcreate -i 6 -I 32  -L 30720 -n lv_wls_m_inv  oradata
echodo lvcreate -i 6 -I 32  -L 30720 -n lv_wls_m_inv_idx oradata
echodo lvcreate -i 6 -I 32  -L 12288 -n lv_wls_m_lo  oradata
echodo lvcreate -i 6 -I 32  -L 65664 -n lv_wls_m_parts  oradata
echodo lvcreate -i 6 -I 32  -L 102400 -n lv_wls_m_wo  oradata
echodo lvcreate -i 6 -I 32  -L 102400 -n lv_wls_m_wo_idx  oradata

echodo lvcreate -i 6 -I 32  -L 12288 -n lv_wls_o_item  oradata
echodo lvcreate -i 6 -I 32  -L 102528 -n lv_wls_o_ordl  oradata
echodo lvcreate -i 6 -I 32  -L 49152 -n lv_wls_o_ords  oradata

echodo lvcreate -i 6 -I 32  -L 28800 -n lv_wls_s_comp  oradata
echodo lvcreate -i 6 -I 32  -L 49152 -n lv_wls_s_po  oradata
echodo lvcreate -i 6 -I 32  -L 61440 -n lv_wls_s_sc  oradata
echodo lvcreate -i 6 -I 32  -L 3072 -n lv_wls_s_site  oradata
echodo lvcreate -i 6 -I 32  -L 3072 -n lv_wls_s_supp  oradata

echodo lvcreate -i 6 -I 32  -L 3072 -n lv_wls_u_seq  oradata

echodo lvcreate -i 6 -I 32  -L 33024 -n lv_wls_llr  oradata

echodo lvcreate -i 4 -I 32  -L 921600 -n lv_wls_slog1  oralog
echodo lvcreate -i 4 -I 32  -L 921600 -n lv_wls_slog2  oralog

echodo chown oracle:dba /dev/mapper/oradata-*
echodo chown oracle:dba /dev/mapper/oralog-*
