#!/bin/sh

####################
# Set the database and database directory vars
#####################
DB=${ORACLE_SID}
LLR=?/dbs/llr_${DB}

sqlplus <<EOT
CONNECT / as sysdba
DROP TABLESPACE llr_ts INCLUDING CONTENTS;
CREATE TABLESPACE llr_ts
        DATAFILE '${LLR}' SIZE 8000M REUSE
        EXTENT MANAGEMENT LOCAL UNIFORM SIZE 1M;
EXIT
EOT

