#!/bin/ksh

export PATH=${PATH}:/usr/sbin:/sbin

echodo ()
{
        echo $*
        $*
}

# Create PVs
echodo pvcreate /dev/sdk1 /dev/sdbf1 /dev/sddk1 /dev/sdet1 /dev/sdfm1 /dev/sdhh1
echodo pvcreate /dev/sdja1 /dev/sdkr1 /dev/sdik1 /dev/sdkb1


# Create VGs
echodo vgcreate oradata /dev/sdk1 /dev/sdbf1 /dev/sddk1 /dev/sdet1 /dev/sdfm1 /dev/sdhh1
echodo vgcreate oralog /dev/sdja1 /dev/sdkr1 /dev/sdik1 /dev/sdkb1



# Alter status of VGS
echodo vgchange -a y oradata
echodo vgchange -a y oralog

